@@ -14,9 +14,9 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, List, Type, Union, overload
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .literals import (
     AlarmTypeType,
@@ -101,24 +101,33 @@ class Exceptions:
     ResourceNotFoundException: Type[BotocoreClientError]
 
 
-class CloudWatchClient:
+class CloudWatchClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        CloudWatchClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#can_paginate)
         """
 
     def delete_alarms(self, *, AlarmNames: List[str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.delete_alarms)
+        Deletes the specified alarms.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.delete_alarms)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#delete_alarms)
         """
 
@@ -131,25 +140,33 @@ class CloudWatchClient:
         Dimensions: List["DimensionTypeDef"] = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.delete_anomaly_detector)
+        Deletes the specified anomaly detection model from your account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.delete_anomaly_detector)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#delete_anomaly_detector)
         """
 
     def delete_dashboards(self, *, DashboardNames: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.delete_dashboards)
+        Deletes all dashboards that you specify.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.delete_dashboards)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#delete_dashboards)
         """
 
     def delete_insight_rules(self, *, RuleNames: List[str]) -> DeleteInsightRulesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.delete_insight_rules)
+        Permanently deletes the specified Contributor Insights rules.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.delete_insight_rules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#delete_insight_rules)
         """
 
     def delete_metric_stream(self, *, Name: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.delete_metric_stream)
+        Permanently deletes the metric stream that you specify.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.delete_metric_stream)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#delete_metric_stream)
         """
 
@@ -159,14 +176,16 @@ class CloudWatchClient:
         AlarmName: str = None,
         AlarmTypes: List[AlarmTypeType] = None,
         HistoryItemType: HistoryItemTypeType = None,
-        StartDate: datetime = None,
-        EndDate: datetime = None,
+        StartDate: Union[datetime, str] = None,
+        EndDate: Union[datetime, str] = None,
         MaxRecords: int = None,
         NextToken: str = None,
         ScanBy: ScanByType = None
     ) -> DescribeAlarmHistoryOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarm_history)
+        Retrieves the history for the specified alarm.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarm_history)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#describe_alarm_history)
         """
 
@@ -184,7 +203,9 @@ class CloudWatchClient:
         NextToken: str = None
     ) -> DescribeAlarmsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarms)
+        Retrieves the specified alarms.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarms)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#describe_alarms)
         """
 
@@ -200,7 +221,9 @@ class CloudWatchClient:
         Unit: StandardUnitType = None
     ) -> DescribeAlarmsForMetricOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarms_for_metric)
+        Retrieves the alarms for the specified metric.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarms_for_metric)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#describe_alarms_for_metric)
         """
 
@@ -214,7 +237,9 @@ class CloudWatchClient:
         Dimensions: List["DimensionTypeDef"] = None
     ) -> DescribeAnomalyDetectorsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.describe_anomaly_detectors)
+        Lists the anomaly detection models that you have created in your account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.describe_anomaly_detectors)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#describe_anomaly_detectors)
         """
 
@@ -222,31 +247,41 @@ class CloudWatchClient:
         self, *, NextToken: str = None, MaxResults: int = None
     ) -> DescribeInsightRulesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.describe_insight_rules)
+        Returns a list of all the Contributor Insights rules in your account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.describe_insight_rules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#describe_insight_rules)
         """
 
     def disable_alarm_actions(self, *, AlarmNames: List[str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.disable_alarm_actions)
+        Disables the actions for the specified alarms.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.disable_alarm_actions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#disable_alarm_actions)
         """
 
     def disable_insight_rules(self, *, RuleNames: List[str]) -> DisableInsightRulesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.disable_insight_rules)
+        Disables the specified Contributor Insights rules.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.disable_insight_rules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#disable_insight_rules)
         """
 
     def enable_alarm_actions(self, *, AlarmNames: List[str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.enable_alarm_actions)
+        Enables the actions for the specified alarms.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.enable_alarm_actions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#enable_alarm_actions)
         """
 
     def enable_insight_rules(self, *, RuleNames: List[str]) -> EnableInsightRulesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.enable_insight_rules)
+        Enables the specified Contributor Insights rules.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.enable_insight_rules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#enable_insight_rules)
         """
 
@@ -258,13 +293,17 @@ class CloudWatchClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#generate_presigned_url)
         """
 
     def get_dashboard(self, *, DashboardName: str) -> GetDashboardOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.get_dashboard)
+        Displays the details of the dashboard that you specify.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.get_dashboard)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_dashboard)
         """
 
@@ -272,15 +311,18 @@ class CloudWatchClient:
         self,
         *,
         RuleName: str,
-        StartTime: datetime,
-        EndTime: datetime,
+        StartTime: Union[datetime, str],
+        EndTime: Union[datetime, str],
         Period: int,
         MaxContributorCount: int = None,
         Metrics: List[str] = None,
         OrderBy: str = None
     ) -> GetInsightRuleReportOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.get_insight_rule_report)
+        This operation returns the time series data collected by a Contributor Insights
+        rule.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.get_insight_rule_report)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_insight_rule_report)
         """
 
@@ -288,15 +330,18 @@ class CloudWatchClient:
         self,
         *,
         MetricDataQueries: List["MetricDataQueryTypeDef"],
-        StartTime: datetime,
-        EndTime: datetime,
+        StartTime: Union[datetime, str],
+        EndTime: Union[datetime, str],
         NextToken: str = None,
         ScanBy: ScanByType = None,
         MaxDatapoints: int = None,
-        LabelOptions: LabelOptionsTypeDef = None
+        LabelOptions: "LabelOptionsTypeDef" = None
     ) -> GetMetricDataOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_data)
+        You can use the `GetMetricData` API to retrieve as many as 500 different metrics
+        in a single request, with a total of as many as 100,800 data points.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_data)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_metric_data)
         """
 
@@ -305,8 +350,8 @@ class CloudWatchClient:
         *,
         Namespace: str,
         MetricName: str,
-        StartTime: datetime,
-        EndTime: datetime,
+        StartTime: Union[datetime, str],
+        EndTime: Union[datetime, str],
         Period: int,
         Dimensions: List["DimensionTypeDef"] = None,
         Statistics: List[StatisticType] = None,
@@ -314,13 +359,17 @@ class CloudWatchClient:
         Unit: StandardUnitType = None
     ) -> GetMetricStatisticsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_statistics)
+        Gets statistics for the specified metric.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_statistics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_metric_statistics)
         """
 
     def get_metric_stream(self, *, Name: str) -> GetMetricStreamOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_stream)
+        Returns information about the metric stream that you specify.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_stream)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_metric_stream)
         """
 
@@ -328,7 +377,10 @@ class CloudWatchClient:
         self, *, MetricWidget: str, OutputFormat: str = None
     ) -> GetMetricWidgetImageOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_widget_image)
+        You can use the `GetMetricWidgetImage` API to retrieve a snapshot graph of one
+        or more Amazon CloudWatch metrics as a bitmap image.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_widget_image)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_metric_widget_image)
         """
 
@@ -336,7 +388,9 @@ class CloudWatchClient:
         self, *, DashboardNamePrefix: str = None, NextToken: str = None
     ) -> ListDashboardsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.list_dashboards)
+        Returns a list of the dashboards for your account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.list_dashboards)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#list_dashboards)
         """
 
@@ -344,7 +398,9 @@ class CloudWatchClient:
         self, *, NextToken: str = None, MaxResults: int = None
     ) -> ListMetricStreamsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.list_metric_streams)
+        Returns a list of metric streams in this account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.list_metric_streams)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#list_metric_streams)
         """
 
@@ -353,18 +409,22 @@ class CloudWatchClient:
         *,
         Namespace: str = None,
         MetricName: str = None,
-        Dimensions: List[DimensionFilterTypeDef] = None,
+        Dimensions: List["DimensionFilterTypeDef"] = None,
         NextToken: str = None,
         RecentlyActive: Literal["PT3H"] = None
     ) -> ListMetricsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.list_metrics)
+        List the specified metrics.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.list_metrics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#list_metrics)
         """
 
     def list_tags_for_resource(self, *, ResourceARN: str) -> ListTagsForResourceOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.list_tags_for_resource)
+        Displays the tags associated with a CloudWatch resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#list_tags_for_resource)
         """
 
@@ -378,7 +438,9 @@ class CloudWatchClient:
         Configuration: "AnomalyDetectorConfigurationTypeDef" = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.put_anomaly_detector)
+        Creates an anomaly detection model for a CloudWatch metric.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.put_anomaly_detector)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_anomaly_detector)
         """
 
@@ -395,13 +457,18 @@ class CloudWatchClient:
         Tags: List["TagTypeDef"] = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.put_composite_alarm)
+        Creates or updates a *composite alarm*.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.put_composite_alarm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_composite_alarm)
         """
 
     def put_dashboard(self, *, DashboardName: str, DashboardBody: str) -> PutDashboardOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.put_dashboard)
+        Creates a dashboard if it does not already exist, or updates an existing
+        dashboard.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.put_dashboard)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_dashboard)
         """
 
@@ -414,7 +481,9 @@ class CloudWatchClient:
         Tags: List["TagTypeDef"] = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.put_insight_rule)
+        Creates a Contributor Insights rule.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.put_insight_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_insight_rule)
         """
 
@@ -445,13 +514,18 @@ class CloudWatchClient:
         ThresholdMetricId: str = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_alarm)
+        Creates or updates an alarm and associates it with the specified metric, metric
+        math expression, or anomaly detection model.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_alarm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_metric_alarm)
         """
 
-    def put_metric_data(self, *, Namespace: str, MetricData: List[MetricDatumTypeDef]) -> None:
+    def put_metric_data(self, *, Namespace: str, MetricData: List["MetricDatumTypeDef"]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_data)
+        Publishes metric data points to Amazon CloudWatch.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_data)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_metric_data)
         """
 
@@ -467,7 +541,9 @@ class CloudWatchClient:
         Tags: List["TagTypeDef"] = None
     ) -> PutMetricStreamOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_stream)
+        Creates or updates a metric stream.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_stream)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_metric_stream)
         """
 
@@ -480,31 +556,41 @@ class CloudWatchClient:
         StateReasonData: str = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.set_alarm_state)
+        Temporarily sets the state of an alarm for testing purposes.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.set_alarm_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#set_alarm_state)
         """
 
     def start_metric_streams(self, *, Names: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.start_metric_streams)
+        Starts the streaming of metrics for one or more of your metric streams.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.start_metric_streams)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#start_metric_streams)
         """
 
     def stop_metric_streams(self, *, Names: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.stop_metric_streams)
+        Stops the streaming of metrics for one or more of your metric streams.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.stop_metric_streams)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#stop_metric_streams)
         """
 
     def tag_resource(self, *, ResourceARN: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.tag_resource)
+        Assigns one or more tags (key-value pairs) to the specified CloudWatch resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#tag_resource)
         """
 
     def untag_resource(self, *, ResourceARN: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Client.untag_resource)
+        Removes one or more tags from the specified resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#untag_resource)
         """
 
@@ -513,37 +599,43 @@ class CloudWatchClient:
         self, operation_name: Literal["describe_alarm_history"]
     ) -> DescribeAlarmHistoryPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#describealarmhistorypaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#describealarmhistorypaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_alarms"]) -> DescribeAlarmsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#describealarmspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#describealarmspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_metric_data"]) -> GetMetricDataPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#getmetricdatapaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#getmetricdatapaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_dashboards"]) -> ListDashboardsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#listdashboardspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#listdashboardspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_metrics"]) -> ListMetricsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#listmetricspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#listmetricspaginator)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["alarm_exists"]) -> AlarmExistsWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Waiter.alarm_exists)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#alarmexistswaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExists)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#alarmexistswaiter)
         """
 
     @overload
@@ -551,5 +643,6 @@ class CloudWatchClient:
         self, waiter_name: Literal["composite_alarm_exists"]
     ) -> CompositeAlarmExistsWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Waiter.composite_alarm_exists)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#compositealarmexistswaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExists)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#compositealarmexistswaiter)
         """
