@@ -19,7 +19,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Iterator, List
+from typing import Any, Iterator, List, Union
 
 from boto3.resources.base import ServiceResource as Boto3ServiceResource
 from boto3.resources.collection import ResourceCollection
@@ -60,12 +60,14 @@ __all__ = (
 
 class ServiceResourceAlarmsCollection(ResourceCollection):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.ServiceResource.alarms)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.ServiceResource.alarms)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#serviceresourcealarmscollection)
     """
 
     def all(self) -> "ServiceResourceAlarmsCollection":
-        pass
+        """
+        Get all items from the collection, optionally with a custom page size and item count limit.
+        """
 
     def filter(  # type: ignore
         self,
@@ -80,71 +82,101 @@ class ServiceResourceAlarmsCollection(ResourceCollection):
         MaxRecords: int = None,
         NextToken: str = None
     ) -> "ServiceResourceAlarmsCollection":
-        pass
+        """
+        Get items from the collection, passing keyword arguments along as parameters to the underlying service operation, which are typically used to filter the results.
+        """
 
     def delete(self) -> None:
-        pass
+        """
+        Batch method.
+        """
 
     def disable_actions(self) -> None:
-        pass
+        """
+        Batch method.
+        """
 
     def enable_actions(self) -> None:
-        pass
+        """
+        Batch method.
+        """
 
     def limit(self, count: int) -> "ServiceResourceAlarmsCollection":
-        pass
+        """
+        Return at most this many Alarms.
+        """
 
     def page_size(self, count: int) -> "ServiceResourceAlarmsCollection":
-        pass
+        """
+        Fetch at most this many Alarms per service request.
+        """
 
     def pages(self) -> Iterator[List["Alarm"]]:
-        pass
+        """
+        A generator which yields pages of Alarms.
+        """
 
     def __iter__(self) -> Iterator["Alarm"]:
-        pass
+        """
+        A generator which yields Alarms.
+        """
 
 
 class ServiceResourceMetricsCollection(ResourceCollection):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.ServiceResource.metrics)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.ServiceResource.metrics)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#serviceresourcemetricscollection)
     """
 
     def all(self) -> "ServiceResourceMetricsCollection":
-        pass
+        """
+        Get all items from the collection, optionally with a custom page size and item count limit.
+        """
 
     def filter(  # type: ignore
         self,
         *,
         Namespace: str = None,
         MetricName: str = None,
-        Dimensions: List[DimensionFilterTypeDef] = None,
+        Dimensions: List["DimensionFilterTypeDef"] = None,
         NextToken: str = None,
         RecentlyActive: Literal["PT3H"] = None
     ) -> "ServiceResourceMetricsCollection":
-        pass
+        """
+        Get items from the collection, passing keyword arguments along as parameters to the underlying service operation, which are typically used to filter the results.
+        """
 
     def limit(self, count: int) -> "ServiceResourceMetricsCollection":
-        pass
+        """
+        Return at most this many Metrics.
+        """
 
     def page_size(self, count: int) -> "ServiceResourceMetricsCollection":
-        pass
+        """
+        Fetch at most this many Metrics per service request.
+        """
 
     def pages(self) -> Iterator[List["Metric"]]:
-        pass
+        """
+        A generator which yields pages of Metrics.
+        """
 
     def __iter__(self) -> Iterator["Metric"]:
-        pass
+        """
+        A generator which yields Metrics.
+        """
 
 
 class MetricAlarmsCollection(ResourceCollection):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Metric.alarms)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Metric.alarms)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricalarmscollection)
     """
 
     def all(self) -> "MetricAlarmsCollection":
-        pass
+        """
+        Get all items from the collection, optionally with a custom page size and item count limit.
+        """
 
     def filter(  # type: ignore
         self,
@@ -155,33 +187,50 @@ class MetricAlarmsCollection(ResourceCollection):
         Period: int = None,
         Unit: StandardUnitType = None
     ) -> "MetricAlarmsCollection":
-        pass
+        """
+        Get items from the collection, passing keyword arguments along as parameters to the underlying service operation, which are typically used to filter the results.
+        """
 
     def delete(self) -> None:
-        pass
+        """
+        Batch method.
+        """
 
     def disable_actions(self) -> None:
-        pass
+        """
+        Batch method.
+        """
 
     def enable_actions(self) -> None:
-        pass
+        """
+        Batch method.
+        """
 
     def limit(self, count: int) -> "MetricAlarmsCollection":
-        pass
+        """
+        Return at most this many Alarms.
+        """
 
     def page_size(self, count: int) -> "MetricAlarmsCollection":
-        pass
+        """
+        Fetch at most this many Alarms per service request.
+        """
 
     def pages(self) -> Iterator[List["Alarm"]]:
-        pass
+        """
+        A generator which yields pages of Alarms.
+        """
 
     def __iter__(self) -> Iterator["Alarm"]:
-        pass
+        """
+        A generator which yields Alarms.
+        """
 
 
 class Alarm(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarm)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarm)
     """
 
     alarm_name: str
@@ -216,7 +265,9 @@ class Alarm(Boto3ServiceResource):
 
     def delete(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Alarm.delete)
+        Deletes the specified alarms.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Alarm.delete)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmdelete-method)
         """
 
@@ -225,44 +276,58 @@ class Alarm(Boto3ServiceResource):
         *,
         AlarmTypes: List[AlarmTypeType] = None,
         HistoryItemType: HistoryItemTypeType = None,
-        StartDate: datetime = None,
-        EndDate: datetime = None,
+        StartDate: Union[datetime, str] = None,
+        EndDate: Union[datetime, str] = None,
         MaxRecords: int = None,
         NextToken: str = None,
         ScanBy: ScanByType = None
     ) -> DescribeAlarmHistoryOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Alarm.describe_history)
+        Retrieves the history for the specified alarm.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Alarm.describe_history)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmdescribe_history-method)
         """
 
     def disable_actions(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Alarm.disable_actions)
+        Disables the actions for the specified alarms.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Alarm.disable_actions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmdisable_actions-method)
         """
 
     def enable_actions(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Alarm.enable_actions)
+        Enables the actions for the specified alarms.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Alarm.enable_actions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmenable_actions-method)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Alarm.get_available_subresources)
+        Returns a list of all the available sub-resources for this Resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Alarm.get_available_subresources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmget_available_subresources-method)
         """
 
     def load(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Alarm.load)
+        Calls :py:meth:`CloudWatch.Client.describe_alarms` to update the attributes of
+        the Alarm resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Alarm.load)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmload-method)
         """
 
     def reload(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Alarm.reload)
+        Calls :py:meth:`CloudWatch.Client.describe_alarms` to update the attributes of
+        the Alarm resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Alarm.reload)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmreload-method)
         """
 
@@ -270,7 +335,9 @@ class Alarm(Boto3ServiceResource):
         self, *, StateValue: StateValueType, StateReason: str, StateReasonData: str = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Alarm.set_state)
+        Temporarily sets the state of an alarm for testing purposes.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Alarm.set_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmset_state-method)
         """
 
@@ -280,7 +347,8 @@ _Alarm = Alarm
 
 class Metric(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metric)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metric)
     """
 
     metric_name: str
@@ -291,15 +359,17 @@ class Metric(Boto3ServiceResource):
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Metric.get_available_subresources)
+        Returns a list of all the available sub-resources for this Resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Metric.get_available_subresources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricget_available_subresources-method)
         """
 
     def get_statistics(
         self,
         *,
-        StartTime: datetime,
-        EndTime: datetime,
+        StartTime: Union[datetime, str],
+        EndTime: Union[datetime, str],
         Period: int,
         Dimensions: List["DimensionTypeDef"] = None,
         Statistics: List[StatisticType] = None,
@@ -307,13 +377,18 @@ class Metric(Boto3ServiceResource):
         Unit: StandardUnitType = None
     ) -> GetMetricStatisticsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Metric.get_statistics)
+        Gets statistics for the specified metric.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Metric.get_statistics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricget_statistics-method)
         """
 
     def load(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Metric.load)
+        Calls :py:meth:`CloudWatch.Client.list_metrics` to update the attributes of the
+        Metric resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Metric.load)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricload-method)
         """
 
@@ -342,19 +417,27 @@ class Metric(Boto3ServiceResource):
         ThresholdMetricId: str = None
     ) -> _Alarm:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Metric.put_alarm)
+        Creates or updates an alarm and associates it with the specified metric, metric
+        math expression, or anomaly detection model.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Metric.put_alarm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricput_alarm-method)
         """
 
     def put_data(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Metric.put_data)
+        Publishes metric data points to Amazon CloudWatch.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Metric.put_data)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricput_data-method)
         """
 
     def reload(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.Metric.reload)
+        Calls :py:meth:`CloudWatch.Client.list_metrics` to update the attributes of the
+        Metric resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Metric.reload)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricreload-method)
         """
 
@@ -364,7 +447,8 @@ _Metric = Metric
 
 class CloudWatchServiceResource(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.ServiceResource)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.ServiceResource)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html)
     """
 
     alarms: ServiceResourceAlarmsCollection
@@ -372,18 +456,24 @@ class CloudWatchServiceResource(Boto3ServiceResource):
 
     def Alarm(self, name: str) -> _Alarm:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
+        Creates a Alarm resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#cloudwatchserviceresourcealarm-method)
         """
 
     def Metric(self, namespace: str, name: str) -> _Metric:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
+        Creates a Metric resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#cloudwatchserviceresourcemetric-method)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/cloudwatch.html#CloudWatch.ServiceResource.get_available_subresources)
+        Returns a list of all the available sub-resources for this Resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.ServiceResource.get_available_subresources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#cloudwatchserviceresourceget_available_subresources-method)
         """
